==> xlniuxdata-vipgame-1.0.30-20150929.081848-31-sources.jar: com/xunlei/niux/data/vipgame/bo/TriggerMessageBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo;

import java.util.List;
import com.ferret.common.dao.BaseDao;
import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.vo.Page;
import com.xunlei.common.util.XLRuntimeException;
import com.xunlei.niux.data.vipgame.vo.TriggerMessage;
import com.xunlei.niux.data.vipgame.vo.TriggerTips;
import com.xunlei.niux.data.vipgame.vo.TriggerTipsUid;


/**
 * 触达消息
 * @author lisu
 * @date 2013-10-25
 * @Descripter:
 */
public class TriggerMessageBoImpl extends BaseDaoImpl implements TriggerMessageBo {
	private BaseDao baseDao;
	public BaseDao getBaseDao() {
		return baseDao;
	}
	public void setBaseDao(BaseDao baseDao) {
		this.baseDao = baseDao;
	}
	public int getMessageCount(String sql ,Object args[]){	
		return getJdbcTemplate().queryForInt(sql, args);
	}
	public List<TriggerMessage> findTriggerMessage(TriggerMessage cu,Page page){
		return baseDao.findByObject(TriggerMessage.class, cu, page);
	}
	public int count(TriggerMessage cu){
		return baseDao.count(cu);
	}
	public void update(TriggerMessage cu){
		 baseDao.updateById(cu);
	}
	public void insert(TriggerMessage cu) {
		baseDao.insert(cu);
	}
	public void delete(Long seqId) {
		baseDao.deleteById(TriggerMessage.class, seqId);
	}
	public void execute(String sql, List<Object> list) {
		baseDao.execute(sql, list);
		
	}
	public List executeQuery(Class class1, String sql, List list) {       
		return baseDao.executeQuery(class1, sql, list);
	}

    public void saveTriggertipsUid(List<Long> uidList, TriggerTips triggerTips) throws RuntimeException{
        TriggerTips query = new TriggerTips();
        query.setInputBy(triggerTips.getInputBy());
        query.setInputTime(triggerTips.getInputTime());
        baseDao.insert(triggerTips);
        List<TriggerTips> ttList = baseDao.findByObject(TriggerTips.class,query,new Page());
        if(ttList==null){
            logger.error("fatal insert triggertips");
            throw new RuntimeException("fatal insert triggertips");
        }
        TriggerTips newTt = ttList.get(0);
        for(Long uid:uidList){
            if(uid==null)continue;
            TriggerTipsUid ttu = new TriggerTipsUid();
            ttu.setUid(uid);
            ttu.setTriggertipsid(newTt.getSeqid());
            baseDao.insert(ttu);
        }
    }
}

==> xlniuxdata-vipgame-1.0.65-20181220.035135-119-sources.jar: com/xunlei/niux/data/vipgame/bo/TriggerMessageBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo;

import java.util.List;
import com.ferret.common.dao.BaseDao;
import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.vo.Page;
import com.xunlei.common.util.XLRuntimeException;
import com.xunlei.niux.data.vipgame.vo.*;


/**
 * 触达消息
 * @author lisu
 * @date 2013-10-25
 * @Descripter:
 */
public class TriggerMessageBoImpl extends BaseDaoImpl implements TriggerMessageBo {
	private BaseDao baseDao;
	public BaseDao getBaseDao() {
		return baseDao;
	}
	public void setBaseDao(BaseDao baseDao) {
		this.baseDao = baseDao;
	}
	public int getMessageCount(String sql ,Object args[]){	
		return getJdbcTemplate().queryForInt(sql, args);
	}
	public List<TriggerMessage> findTriggerMessage(TriggerMessage cu,Page page){
		return baseDao.findByObject(TriggerMessage.class, cu, page);
	}
	public int count(TriggerMessage cu){
		return baseDao.count(cu);
	}
	public void update(TriggerMessage cu){
		 baseDao.updateById(cu);
	}
	public void insert(TriggerMessage cu) {
		baseDao.insert(cu);
	}
	public void delete(Long seqId) {
		baseDao.deleteById(TriggerMessage.class, seqId);
	}
	public void execute(String sql, List<Object> list) {
		baseDao.execute(sql, list);
		
	}
	public List executeQuery(Class class1, String sql, List list) {       
		return baseDao.executeQuery(class1, sql, list);
	}

    public void saveTriggertipsUid(List<Long> uidList, TriggerTips triggerTips) throws RuntimeException{
        TriggerTips query = new TriggerTips();
        query.setInputBy(triggerTips.getInputBy());
        query.setInputTime(triggerTips.getInputTime());
        baseDao.insert(triggerTips);
        List<TriggerTips> ttList = baseDao.findByObject(TriggerTips.class,query,new Page());
        if(ttList==null){
            logger.error("fatal insert triggertips");
            throw new RuntimeException("fatal insert triggertips");
        }
        TriggerTips newTt = ttList.get(0);
        for(Long uid:uidList){
            if(uid==null)continue;
            TriggerTipsUid ttu = new TriggerTipsUid();
            ttu.setUid(uid);
            ttu.setTriggertipsid(newTt.getSeqid());
            baseDao.insert(ttu);
        }
    }

    public void saveMultimediaTips(List<Long> uidList, MultimediaTips multimediaTips) throws RuntimeException{
        baseDao.insert(multimediaTips);
        for(Long uid:uidList){
            if(uid==null)continue;
            MultimediaTipsUidGroup mtud = new MultimediaTipsUidGroup();
            mtud.setUid(uid);
            mtud.setForUidGroupId(multimediaTips.getForUidGroupId());
            baseDao.insert(mtud);
        }
    }
}
